@@ -111,7 +111,7 @@ void Map::Initialize(v8::Local<v8::Object> target) {
     Nan::SetPrototypeMethod(lcons, "clone", clone);
     Nan::SetPrototypeMethod(lcons, "save", save);
     Nan::SetPrototypeMethod(lcons, "clear", clear);
-    Nan::SetPrototypeMethod(lcons, "toXML", to_string);
+    Nan::SetPrototypeMethod(lcons, "toXML", toXML);
     Nan::SetPrototypeMethod(lcons, "resize", resize);
 
 
@@ -598,13 +598,72 @@ typedef struct {
     Nan::Persistent<v8::Function> cb;
 } query_map_baton_t;
 
-
+/**
+ * Query a `Mapnik#Map` object to retrieve layer and feature data based on an
+ * X and Y `Mapnik#Map` coordinates (use `Map#queryPoint` to query with geographic coordinates).
+ *
+ * @name queryMapPoint
+ * @memberof Map
+ * @instance
+ * @param {number} x - x coordinate
+ * @param {number} y - y coordinate
+ * @param {Object} [options]
+ * @param {String|number} [options.layer] - layer name (string) or index (positive integer, 0 index)
+ * to query. If left blank, will query all layers.
+ * @param {Function} callback
+ * @returns {Array} array - An array of `Featureset` objects and layer names, which each contain their own
+ * `Feature` objects.
+ * @example
+ * // iterate over the first layer returned and get all attribute information for each feature
+ * map.queryMapPoint(10, 10, {layer: 0}, function(err, results) {
+ *   if (err) throw err;
+ *   console.log(results); // => [{"layer":"layer_name","featureset":{}}]
+ *   var featureset = results[0].featureset;
+ *   var attributes = [];
+ *   var feature;
+ *   while ((feature = featureset.next())) {
+ *     attributes.push(feature.attributes());
+ *   }
+ *   console.log(attributes); // => [{"attr_key": "attr_value"}, {...}, {...}]
+ * });
+ *
+ */
 NAN_METHOD(Map::queryMapPoint)
 {
     abstractQueryPoint(info,false);
     return;
 }
 
+/**
+ * Query a `Mapnik#Map` object to retrieve layer and feature data based on geographic
+ * coordinates of the source data (use `Map#queryMapPoint` to query with XY coordinates).
+ *
+ * @name queryPoint
+ * @memberof Map
+ * @instance
+ * @param {number} x - x geographic coordinate (CRS based on source data)
+ * @param {number} y - y geographic coordinate (CRS based on source data)
+ * @param {Object} [options]
+ * @param {String|number} [options.layer] - layer name (string) or index (positive integer, 0 index)
+ * to query. If left blank, will query all layers.
+ * @param {Function} callback
+ * @returns {Array} array - An array of `Featureset` objects and layer names, which each contain their own
+ * `Feature` objects.
+ * @example
+ * // query based on web mercator coordinates
+ * map.queryMapPoint(-12957605.0331, 5518141.9452, {layer: 0}, function(err, results) {
+ *   if (err) throw err;
+ *   console.log(results); // => [{"layer":"layer_name","featureset":{}}]
+ *   var featureset = results[0].featureset;
+ *   var attributes = [];
+ *   var feature;
+ *   while ((feature = featureset.next())) {
+ *     attributes.push(feature.attributes());
+ *   }
+ *   console.log(attributes); // => [{"attr_key": "attr_value"}, {...}, {...}]
+ * });
+ *
+ */
 NAN_METHOD(Map::queryPoint)
 {
     abstractQueryPoint(info,true);
@@ -1397,9 +1456,22 @@ NAN_METHOD(Map::clone)
     Map* m2 = new Map();
     m2->map_ = std::make_shared<mapnik::Map>(*m->map_);
     v8::Local<v8::Value> ext = Nan::New<v8::External>(m2);
-    info.GetReturnValue().Set(Nan::New(constructor)->GetFunction()->NewInstance(1, &ext));
+    Nan::MaybeLocal<v8::Object> maybe_local = Nan::NewInstance(Nan::New(constructor)->GetFunction(), 1, &ext);
+    if (maybe_local.IsEmpty()) Nan::ThrowError("Could not create new Map instance");
+    else info.GetReturnValue().Set(maybe_local.ToLocalChecked());
 }
 
+/**
+ * Writes the map to an xml file
+ *
+ * @memberof Map
+ * @instance
+ * @name save
+ * @param {string} file path
+ * @example
+ * map.save("path/to/map.xml");
+ */
+
 NAN_METHOD(Map::save)
 {
     if (info.Length() != 1 || !info[0]->IsString())
@@ -1415,7 +1487,16 @@ NAN_METHOD(Map::save)
     return;
 }
 
-NAN_METHOD(Map::to_string)
+/**
+ * Converts the map to an XML string
+ *
+ * @memberof Map
+ * @instance
+ * @name toXML
+ * @example
+ * var xml = map.toXML();
+ */
+NAN_METHOD(Map::toXML)
 {
     Map* m = Nan::ObjectWrap::Unwrap<Map>(info.Holder());
     bool explicit_defaults = false;
@@ -1588,8 +1669,8 @@ struct vector_tile_baton_t {
  * @param {Object} [options={}]
  * @param {Number} [options.buffer_size=0] size of the buffer on the image
  * @param {Number} [options.scale=1.0] scale the image
- * @param {Number} [options.scale_denominator=0.0] 
- * @param {Number} [options.offset_x=0] pixel offset along the x-axis 
+ * @param {Number} [options.scale_denominator=0.0]
+ * @param {Number} [options.offset_x=0] pixel offset along the x-axis
  * @param {Number} [options.offset_y=0] pixel offset along the y-axis
  * @param {String} [options.image_scaling] must be a valid scaling method (used when rendering a vector tile)
  * @param {String} [options.image_format] must be a string and valid image format (used when rendering a vector tile)
@@ -1597,23 +1678,23 @@ struct vector_tile_baton_t {
  * @param {Boolean} [options.strictly_simple=] ensure all geometry is valid according to
  * OGC Simple definition (used when rendering a vector tile)
  * @param {Boolean} [options.multi_polygon_union] union all multipolygons (used when rendering a vector tile)
- * @param {String} [options.fill_type] the fill type used in determining what are holes and what are outer rings. See the 
+ * @param {String} [options.fill_type] the fill type used in determining what are holes and what are outer rings. See the
  * [Clipper documentation](http://www.angusj.com/delphi/clipper/documentation/Docs/Units/ClipperLib/Types/PolyFillType.htm)
  * to learn more about fill types. (used when rendering a vector tile)
  * @param {String} [options.threading_mode] (used when rendering a vector tile)
- * @param {Number} [options.simplify_distance] Simplification works to generalize 
- * geometries before encoding into vector tiles.simplification distance The 
+ * @param {Number} [options.simplify_distance] Simplification works to generalize
+ * geometries before encoding into vector tiles.simplification distance The
  * `simplify_distance` value works in integer space over a 4096 pixel grid and uses
  * the [Douglas-Peucker algorithm](https://en.wikipedia.org/wiki/Ramer%E2%80%93Douglas%E2%80%93Peucker_algorithm).
  * (used when rendering a vector tile)
- * @param {Object} [options.variables] Mapnik 3.x ONLY: A javascript object 
- * containing key value pairs that should be passed into Mapnik as variables 
- * for rendering and for datasource queries. For example if you passed 
+ * @param {Object} [options.variables] Mapnik 3.x ONLY: A javascript object
+ * containing key value pairs that should be passed into Mapnik as variables
+ * for rendering and for datasource queries. For example if you passed
  * `vtile.render(map,image,{ variables : {zoom:1} },cb)` then the `@zoom`
  * variable would be usable in Mapnik symbolizers like `line-width:"@zoom"`
- * and as a token in Mapnik postgis sql sub-selects like 
+ * and as a token in Mapnik postgis sql sub-selects like
  * `(select * from table where some_field > @zoom)` as tmp (used when rendering a vector tile)
- * @param {Boolean} [options.process_all_rings] if `true`, don't assume winding order and ring order of 
+ * @param {Boolean} [options.process_all_rings] if `true`, don't assume winding order and ring order of
  * polygons are correct according to the [`2.0` Mapbox Vector Tile specification](https://github.com/mapbox/vector-tile-spec)
  * (used when rendering a vector tile)
  * @returns {mapnik.Map} rendered image tile
@@ -1635,7 +1716,7 @@ struct vector_tile_baton_t {
  * var vtile = new mapnik.VectorTile(9,112,195);
  * map.render(vtile, {}, function(err, vtile) {
  *     if (err) throw err;
- *     console.log(vtile); // => vector tile object with data from xml 
+ *     console.log(vtile); // => vector tile object with data from xml
  * });
  */
 NAN_METHOD(Map::render)
